Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CloudTrail.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for AWS CloudTrail - AWS Identity and Access Management

# Actions, resources, and condition keys for AWS CloudTrail

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudtrail.html .

AWS CloudTrail (service prefix: `cloudtrail` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS CloudTrail
- Resource types defined by AWS CloudTrail
- Condition keys for AWS CloudTrail

## Actions defined by AWS CloudTrail

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddTags | Grants permission to add one or more tags to a trail, up to a limit of 10 | Tagging | trail* |  |
CreateTrail | Grants permission to create a trail that specifies the settings for delivery of log data to an Amazon S3 bucket | Write | trail* |  | s3:PutObject
DeleteTrail | Grants permission to delete a trail | Write | trail* |  |
DescribeTrails | Grants permission to list settings for the trails associated with the current region for your account | Read |  |  |
GetEventSelectors | Grants permission to list settings for event selectors configured for a trail | Read | trail* |  |
GetInsightSelectors | Grants permission to list CloudTrail Insights selectors that are configured for a trail | Read | trail* |  |
GetTrail | Grants permission to list settings for the trail | Read |  |  |
GetTrailStatus | Grants permission to retrieve a JSON-formatted list of information about the specified trail | Read | trail* |  |
ListPublicKeys | Grants permission to list the public keys whose private keys were used to sign trail digest files within a specified time range | Read |  |  |
ListTags | Grants permission to list the tags for trails in the current region | Read | trail* |  |
ListTrails | Grants permission to list trails associated with the current region for your account | List |  |  |
LookupEvents | Grants permission to look up API activity events captured by CloudTrail that create, update, or delete resources in your account | Read |  |  |
PutEventSelectors | Grants permission to create and update event selectors for a trail | Write | trail* |  |
PutInsightSelectors | Grants permission to create and update CloudTrail Insights selectors for a trail | Write | trail* |  |
RemoveTags | Grants permission to remove tags from a trail | Tagging | trail* |  |
StartLogging | Grants permission to start the recording of AWS API calls and log file delivery for a trail | Write | trail* |  |
StopLogging | Grants permission to stop the recording of AWS API calls and log file delivery for a trail | Write | trail* |  |
UpdateTrail | Grants permission to update the settings that specify delivery of log files | Write | trail* |  |

## Resource types defined by AWS CloudTrail

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Note

For policies that control access to CloudTrail actions, the Resource element is always set to "*". For information about using resource ARNs in an IAM policy, see Granting Custom Permissions in the AWS CloudTrail User Guide .

Resource types | ARN | Condition keys
--- | --- | ---
trail | `arn:$ { Partition}:cloudtrail:$ { Region}:$ { Account}:trail/$ { TrailName}` |

## Condition keys for AWS CloudTrail

CloudTrail has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.